/* Programma client */

import java.io.*;
import java.rmi.*;

public class ChatClient {

  private static final int DEFAULT_PORT = 1099;

  public static void main(String args[]) {

    String hostName = null;
    int portNum = -1;

    // Controllo dei parametri della riga di comando
    if (args.length != 1 && args.length != 2) {
      System.out.println("Sintassi: ChatClient NomeHost [registryPort]");
      System.exit(1);
    } else {
      hostName = args[0];
      if (args.length == 2) {
        try {
          portNum = Integer.parseInt(args[1]);
        }
        catch (Exception e) {
          System.out
              .println("Sintassi: ChatClient NomeHost [registryPort], registryPort intero");
          System.exit(2);
        }
      } else
        portNum = DEFAULT_PORT;
    }

    // Impostazione del SecurityManager
    if (System.getSecurityManager() == null) {
      System.setSecurityManager(new RMISecurityManager());
    }

    try {
      InputStreamReader is = new InputStreamReader(System.in);
      BufferedReader br = new BufferedReader(is);
      String registryURL = "rmi://" + hostName + ":" + portNum + "/chat";

      /* recupero riferimento al server */
      ChatServerInterface server_ref = (ChatServerInterface) Naming
          .lookup(registryURL);
      System.out.println("Lookup completed ");

      /* istanziazione implementazione interfaccia remota del client */
      System.out.print("What is your name? ");
      String name = br.readLine();

      ChatClientImpl client_ref = new ChatClientImpl(name);

      /* ingresso nella chat */
      System.out.println("Registering for chat");
      server_ref.register(client_ref);

      /* ciclo di permanenza nella chat room */
      System.out.println("Enter messages, EOF to exit");
      String message;
      while ((message = br.readLine()) != null) {
        server_ref.saySomething(message, client_ref);
      }

      /* uscita dalla chat */
      server_ref.unregister(client_ref);
      System.out.println("Unregistered from chat");
      System.exit(0);
    } // end try
    catch (Exception e) {
      System.out.println("Exception in ChatClient: " + e);
      System.exit(1);
    } // end catch
  } //end main
}//end class
