/* Programma server */

import java.rmi.*;
import java.rmi.registry.Registry;
import java.rmi.registry.LocateRegistry;
import java.io.*;

public class ChatServer {

  private static final int DEFAULT_PORT = 1099;

  public static void main(String args[]) {

    InputStreamReader is = new InputStreamReader(System.in);
    BufferedReader br = new BufferedReader(is);
    String registryURL;
    int RMIPortNum = -1;

    // Controllo dei parametri della riga di comando
    if (args.length != 0 && args.length != 1) {
      System.out.println("Sintassi: ChatServer [registryPort]");
      System.exit(1);
    }
    if (args.length == 1) {
      try {
        RMIPortNum = Integer.parseInt(args[0]);
      }
      catch (Exception e) {
        System.out
            .println("Sintassi: ChatServer [registryPort], registryPort intero");
        System.exit(2);
      }
    } else
      RMIPortNum = DEFAULT_PORT;

    // Impostazione del SecurityManager
    if (System.getSecurityManager() == null) {
      System.setSecurityManager(new RMISecurityManager());
    }

    try {
      startRegistry(RMIPortNum);

      /* istanziazione del server e 
       pubblicazione sul registry */
      ChatServerImpl server_ref = new ChatServerImpl();
      registryURL = "rmi://localhost:" + RMIPortNum + "/chat";
      Naming.rebind(registryURL, server_ref);
      System.out.println("Chat Server ready");
    } // end try
    catch (Exception re) {
      System.out.println("Exception in ChatServer.main: " + re);
      System.exit(1);
    } // end catch
  } // end main

  /* metodo che verifica se c gi un registry attivo sullhost e porta indicati, e se non c lo crea */
  private static void startRegistry(int RMIPortNum) throws RemoteException {
    try {
      Registry registry = LocateRegistry.getRegistry(RMIPortNum);
      registry.list();
    }
    catch (RemoteException e) {
      Registry registry = LocateRegistry.createRegistry(RMIPortNum);
    }
  } // end startRegistry

} // end class