/* Implementazione oggetto remoto server */

import java.rmi.*;
import java.rmi.server.*;
import java.util.Vector;

public class ChatServerImpl extends UnicastRemoteObject implements
    ChatServerInterface {

  private Vector clientList;

  public ChatServerImpl() throws RemoteException {
    super();
    clientList = new Vector();
  }

  /*
   * metodo di registrazione: inserisce in una lista il client che vuole
   * registrarsi
   */
  public synchronized void register(ChatClientInterface client_ref)
      throws RemoteException {

    if (!(clientList.contains(client_ref))) {
      clientList.addElement(client_ref);
      System.out.println("Registered new client");
      String callback_msg = "Entrance of " + client_ref.name();
      doCallbacks(callback_msg);
    } // end if
    else
      System.out.println("Register: client already registered.");

  } // end register

  /* metodo di invio di un messaggio */
  public void saySomething(String message, ChatClientInterface client_ref)
      throws java.rmi.RemoteException {

    String callback_msg = client_ref.name() + " :" + message;
    doCallbacks(callback_msg);
  } // end saySomething

  /*
   * metodo di cancellazione: elimina dalla lista il client che vuole
   * cancellarsi
   */
  public synchronized void unregister(ChatClientInterface client_ref)
      throws RemoteException {

    if (clientList.removeElement(client_ref)) {
      System.out.println("Unregistered client");
      String callback_msg = "Exit of " + client_ref.name();
      doCallbacks(callback_msg);
    } else
      System.out.println("Unregister: client wasn't registered.");

  } // end unregister

  /*
   * metodo che fa la callback a tutti i client registrati
   */
  private synchronized void doCallbacks(String msg) throws RemoteException {

    System.out.println("***** Callbacks execution *****");

    for (int i = 0; i < clientList.size(); i++) {
      ChatClientInterface nextClient = (ChatClientInterface) clientList
          .elementAt(i);
      nextClient.callback(msg);
    }// end for

  } // end doCallbacks

} // end class